using System;
using System.Collections.Generic;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using Microsoft.SharePoint;

namespace AnnoucementBanners
{
    public class AnnouncementBanner : WebControl
    {
        string _SiteURL = null;
        string _AnnouncementList = null;
        int _ItemLimit = 1;
        string _Title = "Latest announcements";
        bool _TruncateTitle = false;
        Label ErrorMessage = null;
        bool CanReadItems = true;
        SPSite TargetSite = null;
        SPWeb TargetWeb = null;  

        HtmlTable ContentTable;

        public bool TruncateTitle
        {
            get
            {
                return _TruncateTitle;
            }
            set
            {
                _TruncateTitle = value;
            }
        }
        public string SiteURL
        {
            get
            {
                return _SiteURL;
            }
            set
            {
                _SiteURL = value;
            }
        }
        public string AnnouncementList
        {
            get
            {
                return _AnnouncementList;
            }
            set
            {
                _AnnouncementList = value;
            }
        }

        public int ItemLimit
        {
            get
            {
                return _ItemLimit;
            }
            set
            {
                _ItemLimit = value;
            }
        }
        public string Title
        {
            get
            {
                return _Title;
            }
            set
            {
                _Title = value;
            }
        }

        protected override void CreateChildControls()
        {
            TargetSite = new SPSite(SiteURL);
            TargetWeb = TargetSite.OpenWeb();
            
            try
            {
                TargetWeb.Lists[AnnouncementList].CheckPermissions(SPBasePermissions.ViewListItems);
            }
            catch
            {
                CanReadItems = false;
               
            }
            if (CanReadItems)
            {
                ErrorMessage = new Label();//Holds the error message if any
                ErrorMessage.Style.Add(HtmlTextWriterStyle.Color, "red");
                ContentTable = new HtmlTable();//Will contain all the announcements
                ContentTable.Width = "100%";
                ContentTable.Height = "100%";
                ContentTable.Style.Add(HtmlTextWriterStyle.Overflow, "auto");
                HtmlTableRow HeaderRow = new HtmlTableRow();
                HtmlTableCell HeaderCell = new HtmlTableCell();
                HeaderCell.InnerText = Title; //Announcement Title
                HeaderRow.Cells.Add(HeaderCell);
                ContentTable.Rows.Add(HeaderRow);
                GetLatestAnnouncments();//Call to retrieve the announcements
                this.Controls.Add(ContentTable);//Adding our table to the page controls
                this.Controls.Add(ErrorMessage);//Adding our label to the page controls
            }
        }
        private void GetLatestAnnouncments()
        {
            if (SiteURL != null && AnnouncementList != null)//Checking whether the properties were correclty provided
            {
                try
                {

                    SPQuery AnnouncementQuery = new SPQuery();
                    AnnouncementQuery.Query = "<OrderBy><FieldRef Name='Modified' Ascending='FALSE' /></OrderBy>";
                    AnnouncementQuery.ViewFields = "<FieldRef Name='LinkTitleNoMenu' /><FieldRef Name='" +
                        TargetWeb.Lists[AnnouncementList].Fields["Encoded Absolute URL"].InternalName + "' />";
                    AnnouncementQuery.RowLimit = (uint)ItemLimit;
                    foreach (SPListItem AnnItm in TargetWeb.Lists[AnnouncementList].GetItems(AnnouncementQuery))
                    {
                        HtmlTableRow ItmRow = new HtmlTableRow();
                        HtmlTableCell ItmCell = new HtmlTableCell();
                        ItmCell.InnerHtml = "<a href='" + AnnItm["Encoded Absolute URL"].ToString().Substring(0,
                            AnnItm["Encoded Absolute URL"].ToString().LastIndexOf("/") + 1) + "DispForm.aspx?ID=" +
                            AnnItm.ID + "'>" + AnnItm["LinkTitleNoMenu"].ToString() + "</a>";
                        ItmRow.Cells.Add(ItmCell);
                        ContentTable.Rows.Add(ItmRow);
                    }
                    
                }
                catch (Exception Ex)
                {
                    ErrorMessage.Text = Ex.Message;
                }
            }
        }
        protected override void Render(HtmlTextWriter writer)
        {
            if (CanReadItems)
            {
                EnsureChildControls();
                if (ErrorMessage.Text == "")
                {
                    ContentTable.RenderControl(writer);
                }
                else
                {
                    ErrorMessage.RenderControl(writer);
                }
            }//Simply display nothing in case the current user has no read access
        }
    }
}
